/*SourceData:
Raw Dataset with missing/non-missing data
	PatientData: Prepared Dataset with all variables:
	(1) scb_id: identifiable contributor ID; (Categorical)
	(2) patient_id_key: unique ID for each patient; (Categorical)
	(3) Gender: Male/Female; (Categorical)
	(4) Age: Age of patient; (Numeric)
	(5) birth_date: the Date of birth of patient; (Date)
	(6) Zipcode: zip code of each claim filed; (Categorical)
	(7) Total_Charge: Total Costs for each identifiable patient with certain diagnosis; (Numeric)
	(8) pos: place of service; (Categorical)
	(9) plan_type: insurance type or uninsured; (Categorical)
	(10) ICD1: International Statistical Classification of Diseases and Related Health Problems; (Categorical)
	(11) Chronic_indicator: indicator of chronic/non-chronic diseases (Categorical);
	(12) Diagnosis: Categories of major Chronic diseases (Categorical);
	(13) Validation: Identify missing / non-missing data (Categorical);
	(14) Region: Geographic Region Area (Categorical);
	BegDate: The beginning of Sample Data;
	EndDate: The end of Sample Data;
	*/

/*Step 2: Handling Missing Data*/
title "Exhibit 1: Frequency Counts on  Missing/Non-Missing Records";

/*Count the missing/non-missing data*/
proc freq data = Patient_Study_Sample;
	TABLES VALIDATION;
run;

Title "Exhibit 2: Descriptive Statistics: Non-missing Versus All DataSet";
title2 "Distribution of All Datasets";

proc univariate data = Patient_Study_Sample;
	var total_charge;
	histogram;
run;

title2 "Distribution of Non-Missing Dataset";

proc univariate data = temp;
	where validation = 'VALID';
	var log_charge;
	histogram;
run;

title "TTEST between Genders";

proc sort data=temp;
	by gender;

proc ttest data=temp;
	class gender;
	var log_charge;
run;

title "Nonparametric Comparison between Genders";

proc npar1way data = temp wilcoxon;
	class gender;
	var log_charge;
run;

/*Step 3: Baseline - Identify the key factors for Logistic Model*/
/*Counts of Key Factors*/
Title "Exhibit 3: Frequency Counts on Key factors for high-Cost Claims";

proc freq data = Patient_Study_Sample;
	where validation = 'VALID';
	tables gender;
run;

proc freq data = Patient_Study_Sample;
	where validation = 'VALID';
	tables plan_type;
run;

proc freq data = Patient_Study_Sample;
	where validation = 'VALID';
	tables Chronic_Category;
run;

Title "Exhibit 4: Distribution of Average Charges by age and sex";

/*Distribution of Average Charges by age and sex*/
proc sort data = Patient_Study_Sample;
	by age gender;

proc univariate data = Patient_Study_Sample noprint;
	where validation = 'VALID';
	by age gender;
	var total_charge;
	output mean = AvgStatSex;
run;

Title "Exhibit 5: Distribution of Average Charges by age and region";

/*Distribution of Average Charges by age and region*/
proc sort data = Patient_Study_Sample;
	by age region;

proc univariate data = Patient_Study_Sample noprint;
	where validation = 'VALID';
	by age region;
	var total_charge;
	output mean = AvgStatRegion;
run;

Title "Exhibit 6: Distribution of Average Charges by age and Chronic-Disease";

/*Distribution of Average Charges by age and ICD1*/
proc sort data = Patient_Study_Sample;
	by age Chronic_Category;

proc univariate data = Patient_Study_Sample noprint;
	where validation = 'VALID';
	by age Chronic_Category;
	var total_charge;
	output mean = AvgStatICD1;
run;

Title "Exhibit 7: Distribution of Average Charges by age and ICD1";

/*Distribution of Average Charges by age and Chronic-Disease*/
proc sort data = Patient_Study_Sample;
	by age Diagnosis;

proc univariate data = Patient_Study_Sample noprint;
	where validation = 'VALID';
	by age Diagnosis;
	var total_charge;
	output mean = AvgStatDiagnosis;
run;

Title "Exhibit 8: Descriptive Statistics of Medical Charges by Gender, Age Group, Region, Insurance Plan, and Primary Chronic Conditions";

%MACRO DESCR_STAT (DATASOURCE, VARIABLE);
	TITLE "MEDICAL COST ANALYSIS BY &VARIABLE ";

	PROC MEANS DATA=&DATASOURCE N MEAN SUM STDDEV MIN MAX MAXDEC=0;
		WHERE VALIDATION = 'VALID';
		CLASS &VARIABLE;
		VAR TOTAL_CHARGE;
	RUN;

%MEND;

%DESCR_STAT (Patient_Study_Sample, GENDER);
%DESCR_STAT (Patient_Study_Sample, AGE_GROUP);
%DESCR_STAT (Patient_Study_Sample, REGION);
%DESCR_STAT (Patient_Study_Sample, PLAN_TYPE);
%DESCR_STAT (Patient_Study_Sample, CHRONIC_PRIMARY);

Title "Exhibit 9: Baseline Key Factors for High-Cost Identification (ALL_DATA)";

/*Fit Multiple regression model with All Datasets*/

Proc logistic data=Patient_Study_Sample;
	class gender(ref='F') 
		region(ref = 'NE') 
		insurance 
		age_group (ref = '0-18') 
		chronic_primary (ref = 'Diabetes');
	model response(event = 'High_Cost') = 
		gender 
		age_group 
		region 
		insurance 
		chronic_primary;
run;


Title "Exhibit 10: Baseline Key Factors for High-Cost Identification (Valid_DATA)";

Proc logistic data=Patient_Study_Sample;
	where validation = 'VALID';
	class gender(ref='F') 
		region(ref = 'NE') 
		insurance 
		age_group (ref = '0-18') 
		chronic_primary (ref = 'Diabetes');
	model response(event = 'High_Cost') = 
		gender 
		age_group 
		region 
		insurance 
		chronic_primary;
run;

title "Exhibit 11: Multiple Logistic Regression analysis of factors associated with high Charges with valid data";

proc logistic data=Comorbidity_Sample;
	where validation = 'VALID';
	class comorbidity(ref = 'No Chronic Condition');
	model response = comorbidity;
run;


